@@ -238,26 +238,32 @@ on_gdb_copy_clicked (GtkWidget *w, gpointer data)
 void
 on_gdb_save_clicked (GtkWidget *w, gpointer data)
 {
-	GtkWidget *filesel;
+	GtkWidget *filechooser;
 	int response;
 
-	filesel = gtk_file_selection_new (_("Save Backtrace"));
+	filechooser = gtk_file_chooser_dialog_new (_("Save Backtrace"),
+						   NULL,
+						   GTK_FILE_CHOOSER_ACTION_SAVE,
+						   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+						   GTK_STOCK_SAVE, GTK_RESPONSE_OK,
+						   NULL);
+	gtk_window_set_default_size (GTK_WINDOW (filechooser), 600, 400);
  run_save_dialog:
-	response = gtk_dialog_run (GTK_DIALOG (filesel));
+	response = gtk_dialog_run (GTK_DIALOG (filechooser));
 	if (response == GTK_RESPONSE_OK) {
-		const char *file;
+		char *file;
 		GError *gerr = NULL;
 		char *text;
 
-		file = gtk_file_selection_get_filename (GTK_FILE_SELECTION (filesel));
+		file = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (filechooser));
 		text = buddy_get_text ("gdb-text");
-		if (!bb_write_buffer_to_file (GTK_WINDOW (filesel), 
+		if (!bb_write_buffer_to_file (GTK_WINDOW (filechooser), 
 					      _("Please wait while Bug Buddy saves the stack trace..."),
 					      file, text, -1, &gerr)) {
 			if (gerr) {
 				GtkWidget *d;
 				
-				d = gtk_message_dialog_new (GTK_WINDOW (filesel),
+				d = gtk_message_dialog_new (GTK_WINDOW (filechooser),
 							    0,
 							    GTK_MESSAGE_ERROR,
 							    GTK_BUTTONS_OK,
@@ -269,14 +275,16 @@ on_gdb_save_clicked (GtkWidget *w, gpointer data)
 				gtk_widget_destroy (d);
 				g_error_free (gerr);
 			}
+			g_free (file);
 			g_free (text);
 			goto run_save_dialog;
 		}
 
+		g_free (file);
 		g_free (text);
 	}
 	
-	gtk_widget_destroy (filesel);
+	gtk_widget_destroy (filechooser);
 }
 
 void
