@@ -198,17 +198,18 @@ load_products_xml (BugzillaBTS *bts, xmlDoc *doc)
 			for (cur = node->children; cur; cur = cur->next) {
 				d(g_print ("\t\t%s\n", node->name));
 				if (!strcmp (cur->name, "component")) {
-					comp = g_new0 (BugzillaComponent, 1);
-					comp->product = prod;
-					
 					/* This is a workaround for bad generated products.xml
 					   We really need to strict validation on bugzilla side
 					   or rewrote the script generating products.xml*/
 					tmp = xmlGetProp (cur, "value");
-					if (tmp) {
-						xmlFree (tmp);
+					if (!tmp) {
 						continue;
-					}
+					} 
+					xmlFree (tmp);
+
+					comp = g_new0 (BugzillaComponent, 1);
+					comp->product = prod;
+					
 					comp->name        = XML_NODE_GET_PROP (cur, "value");
 					comp->description = XML_NODE_GET_PROP (cur, "description");
 
